@@ -36,6 +36,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <unistd.h>
 #include <sys/procctl.h>
 #endif
+#if HAVE_SECCOMP
+#include "seccomp_filter.h"
+#endif
 
 static void signalHandler(int signum)
 {
@@ -73,8 +76,8 @@ int main(int argc, char* argv[])
 
     // explicitly disable input methods as it makes it impossible to unlock, see BUG 306932
     // but explicitly set on screen keyboard such as maliit is allowed
-    if (qEnvironmentVariableIsSet("QT_IM_MODULE") && qgetenv("QT_IM_MODULE") != QByteArrayLiteral("maliit")) {
-        qputenv("QT_IM_MODULE", QByteArrayLiteral("compose"));
+    if (!qEnvironmentVariableIsSet("QT_IM_MODULE") || (qEnvironmentVariableIsSet("QT_IM_MODULE") && qgetenv("QT_IM_MODULE") != QByteArrayLiteral("maliit"))) {
+        qputenv("QT_IM_MODULE", QByteArrayLiteral("qtvirtualkeyboard"));
     }
     ScreenLocker::UnlockApp app(argc, argv);
     app.setQuitOnLastWindowClosed(false);
@@ -166,6 +169,14 @@ int main(int argc, char* argv[])
             app.setKsldSocket(fd);
         }
     }
+
+    // init the sandbox
+#if HAVE_SECCOMP
+    if (app.supportsSeccomp()) {
+        ScreenLocker::SecComp::init();
+    }
+#endif
+
     app.desktopResized();
 
     // This allow ksmserver to know when the applicaion has actually finished setting itself up.
